{% extends 'base.html' %}

{% block header %}
  <h1>{% block title %}Patterns - Reveal Position/Value{% endblock %}</h1>
{% endblock %}

{% block content %}
  <form method="post">
    <label for="pattern">Pattern</label>
    <input name="pattern" id="pattern" required>
    <label for="char_per_line">Characters/Line</label>
    <input name="char_per_line" id="char_per_line" required>
    <label for="target_line">Line Number</label>
    <input name="target_line" id="target_line" required>
    <label for="target_char">Character Number</label>
    <input name="target_char" id="target_char" required>
    <input type="submit" value="Solve!">
  </form>
{% endblock %}
