"""
MXS is the Math eXploration Solver.
Copyright (C) 2022  Brian Farrell

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published
by the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

Contact: brian.farrell@me.com
"""

from setuptools import find_packages, setup

from mxs.__version__ import __version__

setup(
    name='mxs',
    version=__version__,
    packages=find_packages(),
    include_package_data=True,
    license='AGPLv3',
    zip_safe=False,
    install_requires=[
        'flask',
    ],
    entry_points={
        "console_scripts": [
            "mxs=mxs.cli:main",
        ],
    },
)
